@@ -5,7 +5,7 @@ with open("README.md", "r") as fh:
 
 setuptools.setup(
     name="pycof",
-    version="1.1.42",
+    version="1.2.4",
     author="Florian Felice",
     author_email="florian.felice@outlook.com",
     description="A package for commonly used functions",
@@ -19,9 +19,16 @@ setuptools.setup(
           "psycopg2-binary>=2.7.4",
           "pymysql>=0.9.3",
           "tqdm>=4.35.0",
-          "boto3>=1.9.219",
+          "boto3>=1.16.19",
           "xlrd>=1.2.0",
-          "matplotlib>=3.1.1"
+          "matplotlib>=3.1.1",
+          "sshtunnel>=0.3.1",
+          "dateparser>=1.0.0",
+          "google-api-python-client>=1.12.8",
+          "google-auth-httplib2>=0.0.4",
+          "google-auth-oauthlib>=0.4.2",
+          "google-auth>=1.24.0",
+          "httplib2>=0.18.1"
       ],
     classifiers=[
         "Programming Language :: Python :: 3",
